package com.icetea.studio.iceteastudioplugins;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.GradientDrawable;
import android.util.Log;
import android.util.TypedValue;
import android.view.Gravity;
import android.view.ViewGroup;
import android.widget.TextView;
import android.widget.Toast;

public class Utils {

    public static boolean isNullOrEmpty(String text) {
        return text == null || text.trim().length() < 1;
    }

    public static boolean convertStringToBoolean(String text) {
        if (!isNullOrEmpty(text)) {
            return Boolean.valueOf(text);
        }
        return false;
    }

    public static int getGravity(String gravity) {
        if (!isNullOrEmpty(gravity)) {
            switch (gravity) {
                case "top":
                    return Gravity.TOP;
                case "center":
                    return Gravity.CENTER;
            }
        }
        return Gravity.BOTTOM;
    }

    public static int getToastType(String toastType) {
        if (!isNullOrEmpty(toastType) && toastType.equals("long")) {
            return Toast.LENGTH_LONG;
        }
        return Toast.LENGTH_SHORT;
    }

    public static void showToast(Context context, String msg, String backgroundColor,
                                 String textColor, int toastType, boolean isFullWith, int gravity) {
        if (context != null) {
            Toast toast = Toast.makeText(context, msg, toastType);
            ViewGroup toastLayout = (ViewGroup) toast.getView();

            if (toastLayout != null) {
                toastLayout.setBackgroundColor(Color.parseColor(backgroundColor));
                toastLayout.setPadding(60, 35, 60, 40);
                TextView textView = (TextView) toastLayout.getChildAt(0);

                if (textView != null) {
                    float pixels = TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, 9, context.getResources().getDisplayMetrics());
                    textView.setTextSize(pixels);
                    textView.setGravity(Gravity.CENTER);
                    textView.setTextColor(Color.parseColor(textColor));
                }
            }

            int x = 0;
            int y = 0;

            if (!isFullWith) {
                x = toast.getXOffset();
                y = toast.getYOffset();

                GradientDrawable shape =  new GradientDrawable();
                shape.setCornerRadius(25);
                shape.setColor(Color.parseColor(backgroundColor));

                if(toastLayout != null) {
                    toastLayout.setBackground(shape);
                }
            }

            int toastGravity = isFullWith ? Gravity.FILL_HORIZONTAL | gravity : gravity;
            toast.setGravity(toastGravity, x, y);
            toast.show();
        }
    }


}
